# Simply-ocr 0.0.1

[By Jeroben Guzmán ](https://github.com/jeroguzman) 

<br>

For text extraction from images on a simple way / Para extraer texto de imagenes de forma sencilla

<br>

## 💡 Prerequisites

   [Python 3](https://www.python.org/downloads/release/python-3111/)

<br>

## 📚 Examples

```
from simply_ocr import read_image_en, read_image_es

read_image_en('test.jpg') #for english

read_image_es('test.jpg') #for spanish
```